@@ -27,15 +27,17 @@ usage: wurfl2python.py [options] WURFL_XML_FILE
 
 import sys
 from time import ctime
+
 from pywurfl.wurflprocessor import DeviceHandler, WurflProcessor, op, main
 
 
-__version__ = "4.2.0a"
+__version__ = "4.3.0a"
 __license__ = "LGPL"
 __copyright__ = "Copyright 2004-6, Armand Lynch"
 __author__ = "Armand Lynch <lyncha@users.sourceforge.net>"
 __contributors__ = "Pau Aliagas <pau@newtral.org>"
-__url__ = "http://wurfl.sourceforge.net/python/"
+__url__ = "http://celljam.net/"
+__all__ = ['DeviceSerializer']
 
 
 class DeviceSerializer(DeviceHandler):
@@ -44,7 +46,6 @@ class DeviceSerializer(DeviceHandler):
     new_caps = idstr + "devclass(%s, '''%s''', '''%s''', %s, {%s})\n"
     no_caps = idstr + "devclass(%s, '''%s''', '''%s''', %s, None)\n"
 
-
     def __str__(self):
         s = []
         c = []
@@ -59,9 +60,9 @@ class DeviceSerializer(DeviceHandler):
             try:
                 c.append("'''%s''':%d" % (cap, int(value)))
             except ValueError:
-                if value == "true":
+                if value.lower() == "true":
                     c.append("'''%s''':True" % cap)
-                elif value == "false":
+                elif value.lower() == "false":
                     c.append("'''%s''':False" % cap)
                 else:
                     c.append("'''%s''':'''%s'''" % (cap, value))
@@ -110,7 +111,7 @@ class WurflPythonWriter(WurflProcessor):
 
     def start_process(self):
         version = self.tree.findtext("*/ver").strip()
-        self.outfile.write('"""%s\n\n' % self.outfile.name)
+        self.outfile.write('"""\n%s\n\n' % self.outfile.name)
         self.outfile.write("Generated on: %s\n" % ctime())
         self.outfile.write("Generated by: wurfl2python.py v%s\n" % __version__)
         self.outfile.write('"""\n\n')
