@@ -25,7 +25,7 @@ class WURFLMiddleWare(object):
                                             self.search_algorithm)
         except DeviceNotFound:
             device = devices.select_id('generic')
-        environ['WURFL_DEVICE'] = device
+        environ['wurfl.device'] = device
         return self.application(environ, start_response)
 
 
@@ -36,8 +36,7 @@ def WURFLMiddleWareClosure(application, devices, search_algorithm):
                                                search_algorithm)
         except DeviceNotFound:
             device = devices.select_id('generic')
-        environ['WURFL_DEVICE'] = device
+        environ['wurfl.device'] = device
         return application(environ, start_response)
     return middle_ware
 
-
