@@ -24,15 +24,18 @@ pywurfl - Python tools for processing and querying the Wireless Universal Resour
 
 import re
 from copy import copy
-from exceptions import (BaseException, ActualDeviceRootNotFound, DeviceNotFound,
-                        ExistsException)
+
+from pywurfl.exceptions import (BaseException, ActualDeviceRootNotFound,
+                                DeviceNotFound, ExistsException)
+
 
 __author__ = "Armand Lynch <lyncha@users.sourceforge.net>"
 __contributors__ = "Pau Aliagas <pau@newtral.org>"
 __copyright__ = "Copyright 2006, Armand Lynch"
 __license__ = "LGPL"
 __url__ = "http://celljam.net/"
-__version__ = "6.3.0b"
+__version__ = "6.3.1b"
+__all__ = ['devclass', 'Devices']
 
 
 class RootDevice(object):
